@@ -96,14 +96,14 @@ class DatasetManager:
             blob_service_client = BlobServiceClient.from_connection_string(self.connectionString)
             container_name = self.container
             container_client = blob_service_client.get_container_client(container_name)
-            uri_base = subject+"/"+scanner+"/"+set
+            uri = subject+"/"+scanner+"/"+set+"_"+series+extension
             path_dir = self.localDataRootDir+"/"+subject+"/"+scanner
-            path_base = path_dir+"/"+set
-            print(path_base)
+            path = path_dir+"/"+set+"_"+series+extension
+            print(uri)
             Path(path_dir).mkdir( parents=True, exist_ok=True )
             container_client = blob_service_client.get_container_client(container= container_name) 
-            with open(path_base+"_"+series+extension, "wb") as download_file:
-                download_file.write(container_client.download_blob(uri_base+"_"+series+extension).readall())
+            with open(path, "wb") as download_file:
+                download_file.write(container_client.download_blob(uri).readall())
             return self.loadSingleSeries(subject, scanner, set, series, extension)
 
     def fetchSetFromAzure(self, subject, scanner, set, includeMPRAGE=False, includeTSE=False):
